/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.kubernetes.persistent_volumes_claims;

import org.apache.camel.Category;
import org.apache.camel.Consumer;
import org.apache.camel.Processor;
import org.apache.camel.Producer;
import org.apache.camel.component.kubernetes.AbstractKubernetesEndpoint;
import org.apache.camel.component.kubernetes.KubernetesConfiguration;
import org.apache.camel.spi.UriEndpoint;

/**
 * Perform operations on Kubernetes Persistent Volumes Claims and get notified on Persistent Volumes Claim changes.
 */
@UriEndpoint(firstVersion = "2.17.0", scheme = "kubernetes-persistent-volumes-claims",
             title = "Kubernetes Persistent Volume Claim",
             syntax = "kubernetes-persistent-volumes-claims:masterUrl", producerOnly = true,
             category = { Category.CONTAINER, Category.CLOUD, Category.PAAS })
public class KubernetesPersistentVolumesClaimsEndpoint extends AbstractKubernetesEndpoint {

    public KubernetesPersistentVolumesClaimsEndpoint(
                                                     String uri, KubernetesPersistentVolumesClaimsComponent component,
                                                     KubernetesConfiguration config) {
        super(uri, component, config);
    }

    @Override
    public Producer createProducer() throws Exception {
        return new KubernetesPersistentVolumesClaimsProducer(this);
    }

    @Override
    public Consumer createConsumer(Processor processor) throws Exception {
        throw new IllegalArgumentException("The kubernetes-persistent-volumes-claims doesn't exist");
    }

}
